@@ -1,16 +1,10 @@
 import click
 import sys
 
+from pathlib import Path
+
 from steinbock._cli.utils import OrderedClickGroup
-from steinbock._env import (
-    cellprofiler_binary,
-    cellprofiler_plugin_dir,
-    check_steinbock_version,
-    check_x11,
-    ilastik_binary,
-    run_captured,
-    use_ilastik_env,
-)
+from steinbock._env import check_x11, run_captured, use_ilastik_env
 
 
 @click.group(
@@ -26,11 +20,18 @@ def apps_cmd_group():
     help="Run Ilastik (GUI requires X11)",
     add_help_option=False,
 )
+@click.option(
+    "--ilastik",
+    "ilastik_binary",
+    type=click.STRING,
+    default="/opt/ilastik/run_ilastik.sh",
+    show_default=True,
+    help="Ilastik binary",
+)
 @click.argument("ilastik_args", nargs=-1, type=click.UNPROCESSED)
-@check_steinbock_version
 @check_x11
 @use_ilastik_env
-def ilastik_cmd(ilastik_args, ilastik_env):
+def ilastik_cmd(ilastik_binary, ilastik_args, ilastik_env):
     args = [ilastik_binary] + list(ilastik_args)
     result = run_captured(args, env=ilastik_env)
     sys.exit(result.returncode)
@@ -42,12 +43,29 @@ def ilastik_cmd(ilastik_args, ilastik_env):
     help="Run CellProfiler (GUI requires X11)",
     add_help_option=False,
 )
+@click.option(
+    "--cellprofiler",
+    "cellprofiler_binary",
+    type=click.STRING,
+    default="cellprofiler",
+    show_default=True,
+    help="CellProfiler binary",
+)
+@click.option(
+    "--plugins-directory",
+    "cellprofiler_plugin_dir",
+    type=click.Path(file_okay=False),
+    default="/opt/cellprofiler_plugins",
+    show_default=True,
+    help="Path to the CellProfiler plugin directory",
+)
 @click.argument("cellprofiler_args", nargs=-1, type=click.UNPROCESSED)
-@check_steinbock_version
 @check_x11
-def cellprofiler_cmd(cellprofiler_args):
+def cellprofiler_cmd(
+    cellprofiler_binary, cellprofiler_plugin_dir, cellprofiler_args
+):
     args = [cellprofiler_binary] + list(cellprofiler_args)
-    if not any(arg.startswith("--plugins-directory") for arg in args):
+    if Path(cellprofiler_plugin_dir).exists():
         args.append(f"--plugins-directory={cellprofiler_plugin_dir}")
     result = run_captured(args)
     sys.exit(result.returncode)
